==> ZenTaoPMS.17.4.php5.4_5.6.zip: zentaopms/extension/max/assetlib/lang/en.php <==
<?php
$lang->assetlib->storyLib       = 'Story Lib';
$lang->assetlib->caseLib        = 'Case Lib';
$lang->assetlib->issueLib       = 'Issue Lib';
$lang->assetlib->riskLib        = 'Risk Lib';
$lang->assetlib->opportunityLib = 'Opportunity Lib';
$lang->assetlib->practiceLib    = 'Practice Lib';
$lang->assetlib->componentLib   = 'Component Lib';
$lang->assetlib->browse         = 'Lib';
$lang->assetlib->all            = 'All';
$lang->assetlib->story          = 'Story List';
$lang->assetlib->issue          = 'Issue List';
$lang->assetlib->risk           = 'Risk List';
$lang->assetlib->opportunity    = 'Opportunity List';
$lang->assetlib->practice       = 'Practice List';
$lang->assetlib->component      = 'Component List';
$lang->assetlib->libView        = 'Library Detail';
$lang->assetlib->deleted        = 'Deleted';

$lang->assetlib->allStoryLib       = 'All Story Lib';
$lang->assetlib->allCaseLib        = 'All Case Lib';
$lang->assetlib->allIssueLib       = 'All Issue Lib';
$lang->assetlib->allRiskLib        = 'All Risk Lib';
$lang->assetlib->allOpportunityLib = 'All Opportunity Lib';
$lang->assetlib->allPracticeLib    = 'All Practice Lib';
$lang->assetlib->allComponentLib   = 'All Component Lib';

/* Fields */
$lang->assetlib->id                = 'ID';
$lang->assetlib->name              = 'Name';
$lang->assetlib->desc              = 'Desc';
$lang->assetlib->pri               = 'Pri';
$lang->assetlib->priAB             = 'P';
$lang->assetlib->status            = 'Status';
$lang->assetlib->estimate          = 'Estimate';
$lang->assetlib->createdBy         = 'Created By';
$lang->assetlib->createdDate       = 'Created Date';
$lang->assetlib->approved          = 'Approved';
$lang->assetlib->approvedDate      = 'Approved Date';
$lang->assetlib->assignedTo        = 'Assigned To';
$lang->assetlib->noAssigned        = 'No Assigned';
$lang->assetlib->assignedDate      = 'Assigned Date';
$lang->assetlib->approvedDate      = 'Approved Date';
$lang->assetlib->approveResult     = 'Approve Result';
$lang->assetlib->project           = 'Project';
$lang->assetlib->plan              = 'Plan';
$lang->assetlib->allProject        = 'All Project';
$lang->assetlib->importedBy        = 'Imported By';
$lang->assetlib->importedDate      = 'Imported Date';
$lang->assetlib->approvedBy        = 'Approved By';
$lang->assetlib->sourceStory       = 'Source Story';
$lang->assetlib->sourceIssue       = 'Source Issue';
$lang->assetlib->sourceRisk        = 'Source Risk';
$lang->assetlib->sourceOpportunity = 'Source Opportunity';
$lang->assetlib->sourceDoc         = 'Source Doc';
$lang->assetlib->lastEditedDate    = 'Last Edited Date';

/* Actions */
$lang->assetlib->createStoryLib           = 'Create Story Lib';
$lang->assetlib->createIssueLib           = 'Create Issue Lib';
$lang->assetlib->createRiskLib            = 'Create Risk Lib';
$lang->assetlib->createOpportunityLib     = 'Create Opportunity Lib';
$lang->assetlib->createPracticeLib        = 'Create Practice Lib';
$lang->assetlib->createComponentLib       = 'Create Component Lib';
$lang->assetlib->edit                     = 'Edit';
$lang->assetlib->editStoryLib             = 'Edit Story Lib';
$lang->assetlib->editIssueLib             = 'Edit Issue Lib';
$lang->assetlib->editRiskLib              = 'Edit Risk Lib';
$lang->assetlib->editOpportunityLib       = 'Edit Opportunity Lib';
$lang->assetlib->editPracticeLib          = 'Edit Practice Lib';
$lang->assetlib->editComponentLib         = 'Edit Component Lib';
$lang->assetlib->deleteStoryLib           = 'Delete Story Lib';
$lang->assetlib->deleteIssueLib           = 'Delete Issue Lib';
$lang->assetlib->deleteRiskLib            = 'Delete Risk Lib';
$lang->assetlib->deleteOpportunityLib     = 'Delete Opportunity Lib';
$lang->assetlib->deletePracticeLib        = 'Delete Practice Lib';
$lang->assetlib->deleteComponentLib       = 'Delete Component Lib';
$lang->assetlib->assignToStory            = 'AssignTo Story';
$lang->assetlib->assignToIssue            = 'AssignTo Issue';
$lang->assetlib->assignToRisk             = 'AssignTo Risk';
$lang->assetlib->assignToOpportunity      = 'AssignTo Opportunity';
$lang->assetlib->assignToPractice         = 'AssignTo Practice';
$lang->assetlib->assignToComponent        = 'AssignTo Component';
$lang->assetlib->batchAssignToStory       = 'Batch AssignedTo Story';
$lang->assetlib->batchAssignToIssue       = 'Batch AssignedTo Issue';
$lang->assetlib->batchAssignToRisk        = 'Batch AssignedTo Risk';
$lang->assetlib->batchAssignToOpportunity = 'Batch AssignedTo Opportunity';
$lang->assetlib->batchAssignToPractice    = 'Batch AssignedTo Practice';
$lang->assetlib->batchAssignToComponent   = 'Batch AssignedTo Component';
$lang->assetlib->approve                  = 'Approve';
$lang->assetlib->approveStory             = 'Approve Story';
$lang->assetlib->approveIssue             = 'Approve Issue';
$lang->assetlib->approveRisk              = 'Approve Risk';
$lang->assetlib->approveOpportunity       = 'Approve Opportunity';
$lang->assetlib->approvePractice          = 'Approve Practice';
$lang->assetlib->approveComponent         = 'Approve Component';
$lang->assetlib->batchApproveStory        = 'Batch Approve Story';
$lang->assetlib->batchApproveIssue        = 'Batch Approve Issue';
$lang->assetlib->batchApproveRisk         = 'Batch Approve Risk';
$lang->assetlib->batchApproveOpportunity  = 'Batch Approve Opportunity';
$lang->assetlib->batchApprovePractice     = 'Batch Approve Practice';
$lang->assetlib->batchApproveComponent    = 'Batch Approve Component';
$lang->assetlib->editStory                = 'Edit Story';
$lang->assetlib->editIssue                = 'Edit Issue';
$lang->assetlib->editRisk                 = 'Edit Risk';
$lang->assetlib->editOpportunity          = 'Edit Opportunity';
$lang->assetlib->editPractice             = 'Edit Practice';
$lang->assetlib->editComponent            = 'Edit Component';
$lang->assetlib->removeStory              = 'Remove Story';
$lang->assetlib->removeIssue              = 'Remove Issue';
$lang->assetlib->removeRisk               = 'Remove Risk';
$lang->assetlib->removeOpportunity        = 'Remove Opportunity';
$lang->assetlib->removePractice           = 'Remove Practice';
$lang->assetlib->removeComponent          = 'Remove Component';
$lang->assetlib->batchRemoveStory         = 'Batch Remove Story';
$lang->assetlib->batchRemoveIssue         = 'Batch Remove Issue';
$lang->assetlib->batchRemoveRisk          = 'Batch Remove Risk';
$lang->assetlib->batchRemoveOpportunity   = 'Batch Remove Opportunity';
$lang->assetlib->batchRemovePractice      = 'Batch Remove Practice';
$lang->assetlib->batchRemoveComponent     = 'Batch Remove Component';
$lang->assetlib->remove                   = 'Remove';

$lang->assetlib->view               = 'Library View';
$lang->assetlib->storyLibView       = 'Story Library View';
$lang->assetlib->issueLibView       = 'Issue Library View';
$lang->assetlib->riskLibView        = 'Risk Library View';
$lang->assetlib->opportunityLibView = 'Opportunity Library View';
$lang->assetlib->practiceLibView    = 'Practice Library View';
$lang->assetlib->componentLibView   = 'Component Library View';
$lang->assetlib->storyView          = 'Story View';
$lang->assetlib->issueView          = 'Issue View';
$lang->assetlib->riskView           = 'Risk View';
$lang->assetlib->opportunityView    = 'Opportunity View';
$lang->assetlib->practiceView       = 'Practice View';
$lang->assetlib->componentView      = 'Component View';

$lang->assetlib->import            = 'Import';
$lang->assetlib->importFromProject = 'Import From Project';
$lang->assetlib->importStory       = 'Import Story';
$lang->assetlib->importIssue       = 'Import Issue';
$lang->assetlib->importRisk        = 'Import Risk';
$lang->assetlib->importOpportunity = 'Import Opportunity';
$lang->assetlib->importPractice    = 'Import Practice Doc';
$lang->assetlib->importComponent   = 'Import Component Doc';

$lang->assetlib->selectProject = 'Select Project';
$lang->assetlib->selectProduct = 'Select Product';
$lang->assetlib->selectDocLib  = 'Select Doc Lib';
$lang->assetlib->noProject     = 'No project exists. Please create one first.';

$lang->assetlib->storyLibDelete       = 'Do you want to delete this story library?';
$lang->assetlib->issueLibDelete       = 'Do you want to delete this issue library?';
$lang->assetlib->riskLibDelete        = 'Do you want to delete this risk library?';
$lang->assetlib->opportunityLibDelete = 'Do you want to delete this opportunity library?';
$lang->assetlib->practiceLibDelete    = 'Do you want to delete this practice library?';
$lang->assetlib->componentLibDelete   = 'Do you want to delete this component library?';

$lang->assetlib->confirmDeleteStory       = 'Do you want to remove this story?';
$lang->assetlib->confirmDeleteIssue       = 'Do you want to remove this issue?';
$lang->assetlib->confirmDeleteRisk        = 'Do you want to remove this risk?';
$lang->assetlib->confirmDeleteOpportunity = 'Do you want to remove this opportunity?';
$lang->assetlib->confirmDeletePractice    = 'Do you want to remove this practice?';
$lang->assetlib->confirmDeleteComponent   = 'Do you want to remove this component?';

$lang->assetlib->lib       = 'Library';
$lang->assetlib->selectLib = 'Select Library';
$lang->assetlib->noLibrary = 'No library exists. Please create one first.';

$lang->assetlib->featureBar['all']   = 'All';
$lang->assetlib->featureBar['draft'] = 'Pending';

$lang->assetlib->statusList['active'] = 'Inlib';
$lang->assetlib->statusList['draft']  = 'Pending';

$lang->assetlib->resultList['pass']   = 'Pass';
$lang->assetlib->resultList['reject'] = 'Reject';

$lang->assetlib->byQuery = 'Search';

==> ZenTaoPMS.17.5.php8.0.zip: zentaopms/extension/max/assetlib/lang/en.php <==
<?php
$lang->assetlib->storyLib       = 'Story Lib';
$lang->assetlib->caseLib        = 'Case Lib';
$lang->assetlib->issueLib       = 'Issue Lib';
$lang->assetlib->riskLib        = 'Risk Lib';
$lang->assetlib->opportunityLib = 'Opportunity Lib';
$lang->assetlib->practiceLib    = 'Practice Lib';
$lang->assetlib->componentLib   = 'Component Lib';
$lang->assetlib->browse         = 'Lib';
$lang->assetlib->all            = 'All';
$lang->assetlib->story          = 'Story List';
$lang->assetlib->issue          = 'Issue List';
$lang->assetlib->risk           = 'Risk List';
$lang->assetlib->opportunity    = 'Opportunity List';
$lang->assetlib->practice       = 'Practice List';
$lang->assetlib->component      = 'Component List';
$lang->assetlib->libView        = 'Library Detail';
$lang->assetlib->deleted        = 'Deleted';

$lang->assetlib->allStoryLib       = 'All Story Lib';
$lang->assetlib->allCaseLib        = 'All Case Lib';
$lang->assetlib->allIssueLib       = 'All Issue Lib';
$lang->assetlib->allRiskLib        = 'All Risk Lib';
$lang->assetlib->allOpportunityLib = 'All Opportunity Lib';
$lang->assetlib->allPracticeLib    = 'All Practice Lib';
$lang->assetlib->allComponentLib   = 'All Component Lib';

/* Fields */
$lang->assetlib->id                = 'ID';
$lang->assetlib->name              = 'Name';
$lang->assetlib->desc              = 'Desc';
$lang->assetlib->pri               = 'Pri';
$lang->assetlib->priAB             = 'P';
$lang->assetlib->status            = 'Status';
$lang->assetlib->estimate          = 'Estimate';
$lang->assetlib->createdBy         = 'Created By';
$lang->assetlib->createdDate       = 'Created Date';
$lang->assetlib->approved          = 'Approved';
$lang->assetlib->approvedDate      = 'Approved Date';
$lang->assetlib->assignedTo        = 'Assigned To';
$lang->assetlib->noAssigned        = 'No Assigned';
$lang->assetlib->assignedDate      = 'Assigned Date';
$lang->assetlib->approvedDate      = 'Approved Date';
$lang->assetlib->approveResult     = 'Approve Result';
$lang->assetlib->project           = 'Project';
$lang->assetlib->plan              = 'Plan';
$lang->assetlib->allProject        = 'All Project';
$lang->assetlib->importedBy        = 'Imported By';
$lang->assetlib->importedDate      = 'Imported Date';
$lang->assetlib->approvedBy        = 'Approved By';
$lang->assetlib->sourceStory       = 'Source Story';
$lang->assetlib->sourceIssue       = 'Source Issue';
$lang->assetlib->sourceRisk        = 'Source Risk';
$lang->assetlib->sourceOpportunity = 'Source Opportunity';
$lang->assetlib->sourceDoc         = 'Source Doc';
$lang->assetlib->lastEditedDate    = 'Last Edited Date';

/* Actions */
$lang->assetlib->createStoryLib           = 'Create Story Lib';
$lang->assetlib->createIssueLib           = 'Create Issue Lib';
$lang->assetlib->createRiskLib            = 'Create Risk Lib';
$lang->assetlib->createOpportunityLib     = 'Create Opportunity Lib';
$lang->assetlib->createPracticeLib        = 'Create Practice Lib';
$lang->assetlib->createComponentLib       = 'Create Component Lib';
$lang->assetlib->edit                     = 'Edit';
$lang->assetlib->editStoryLib             = 'Edit Story Lib';
$lang->assetlib->editIssueLib             = 'Edit Issue Lib';
$lang->assetlib->editRiskLib              = 'Edit Risk Lib';
$lang->assetlib->editOpportunityLib       = 'Edit Opportunity Lib';
$lang->assetlib->editPracticeLib          = 'Edit Practice Lib';
$lang->assetlib->editComponentLib         = 'Edit Component Lib';
$lang->assetlib->deleteStoryLib           = 'Delete Story Lib';
$lang->assetlib->deleteIssueLib           = 'Delete Issue Lib';
$lang->assetlib->deleteRiskLib            = 'Delete Risk Lib';
$lang->assetlib->deleteOpportunityLib     = 'Delete Opportunity Lib';
$lang->assetlib->deletePracticeLib        = 'Delete Practice Lib';
$lang->assetlib->deleteComponentLib       = 'Delete Component Lib';
$lang->assetlib->assignToStory            = 'AssignTo Story';
$lang->assetlib->assignToIssue            = 'AssignTo Issue';
$lang->assetlib->assignToRisk             = 'AssignTo Risk';
$lang->assetlib->assignToOpportunity      = 'AssignTo Opportunity';
$lang->assetlib->assignToPractice         = 'AssignTo Practice';
$lang->assetlib->assignToComponent        = 'AssignTo Component';
$lang->assetlib->batchAssignToStory       = 'Batch AssignedTo Story';
$lang->assetlib->batchAssignToIssue       = 'Batch AssignedTo Issue';
$lang->assetlib->batchAssignToRisk        = 'Batch AssignedTo Risk';
$lang->assetlib->batchAssignToOpportunity = 'Batch AssignedTo Opportunity';
$lang->assetlib->batchAssignToPractice    = 'Batch AssignedTo Practice';
$lang->assetlib->batchAssignToComponent   = 'Batch AssignedTo Component';
$lang->assetlib->approve                  = 'Approve';
$lang->assetlib->approveStory             = 'Approve Story';
$lang->assetlib->approveIssue             = 'Approve Issue';
$lang->assetlib->approveRisk              = 'Approve Risk';
$lang->assetlib->approveOpportunity       = 'Approve Opportunity';
$lang->assetlib->approvePractice          = 'Approve Practice';
$lang->assetlib->approveComponent         = 'Approve Component';
$lang->assetlib->batchApproveStory        = 'Batch Approve Story';
$lang->assetlib->batchApproveIssue        = 'Batch Approve Issue';
$lang->assetlib->batchApproveRisk         = 'Batch Approve Risk';
$lang->assetlib->batchApproveOpportunity  = 'Batch Approve Opportunity';
$lang->assetlib->batchApprovePractice     = 'Batch Approve Practice';
$lang->assetlib->batchApproveComponent    = 'Batch Approve Component';
$lang->assetlib->editStory                = 'Edit Story';
$lang->assetlib->editIssue                = 'Edit Issue';
$lang->assetlib->editRisk                 = 'Edit Risk';
$lang->assetlib->editOpportunity          = 'Edit Opportunity';
$lang->assetlib->editPractice             = 'Edit Practice';
$lang->assetlib->editComponent            = 'Edit Component';
$lang->assetlib->removeStory              = 'Remove Story';
$lang->assetlib->removeIssue              = 'Remove Issue';
$lang->assetlib->removeRisk               = 'Remove Risk';
$lang->assetlib->removeOpportunity        = 'Remove Opportunity';
$lang->assetlib->removePractice           = 'Remove Practice';
$lang->assetlib->removeComponent          = 'Remove Component';
$lang->assetlib->batchRemoveStory         = 'Batch Remove Story';
$lang->assetlib->batchRemoveIssue         = 'Batch Remove Issue';
$lang->assetlib->batchRemoveRisk          = 'Batch Remove Risk';
$lang->assetlib->batchRemoveOpportunity   = 'Batch Remove Opportunity';
$lang->assetlib->batchRemovePractice      = 'Batch Remove Practice';
$lang->assetlib->batchRemoveComponent     = 'Batch Remove Component';
$lang->assetlib->remove                   = 'Remove';

$lang->assetlib->view               = 'Library View';
$lang->assetlib->storyLibView       = 'Story Library View';
$lang->assetlib->issueLibView       = 'Issue Library View';
$lang->assetlib->riskLibView        = 'Risk Library View';
$lang->assetlib->opportunityLibView = 'Opportunity Library View';
$lang->assetlib->practiceLibView    = 'Practice Library View';
$lang->assetlib->componentLibView   = 'Component Library View';
$lang->assetlib->storyView          = 'Story View';
$lang->assetlib->issueView          = 'Issue View';
$lang->assetlib->riskView           = 'Risk View';
$lang->assetlib->opportunityView    = 'Opportunity View';
$lang->assetlib->practiceView       = 'Practice View';
$lang->assetlib->componentView      = 'Component View';

$lang->assetlib->import            = 'Import';
$lang->assetlib->importFromProject = 'Import From Project';
$lang->assetlib->importStory       = 'Import Story';
$lang->assetlib->importIssue       = 'Import Issue';
$lang->assetlib->importRisk        = 'Import Risk';
$lang->assetlib->importOpportunity = 'Import Opportunity';
$lang->assetlib->importPractice    = 'Import Practice Doc';
$lang->assetlib->importComponent   = 'Import Component Doc';

$lang->assetlib->selectProject = 'Select Project';
$lang->assetlib->selectProduct = 'Select Product';
$lang->assetlib->selectDocLib  = 'Select Doc Lib';
$lang->assetlib->noProject     = 'No project exists. Please create one first.';

$lang->assetlib->storyLibDelete       = 'Do you want to delete this story library?';
$lang->assetlib->issueLibDelete       = 'Do you want to delete this issue library?';
$lang->assetlib->riskLibDelete        = 'Do you want to delete this risk library?';
$lang->assetlib->opportunityLibDelete = 'Do you want to delete this opportunity library?';
$lang->assetlib->practiceLibDelete    = 'Do you want to delete this practice library?';
$lang->assetlib->componentLibDelete   = 'Do you want to delete this component library?';

$lang->assetlib->confirmDeleteStory       = 'Do you want to remove this story?';
$lang->assetlib->confirmDeleteIssue       = 'Do you want to remove this issue?';
$lang->assetlib->confirmDeleteRisk        = 'Do you want to remove this risk?';
$lang->assetlib->confirmDeleteOpportunity = 'Do you want to remove this opportunity?';
$lang->assetlib->confirmDeletePractice    = 'Do you want to remove this practice?';
$lang->assetlib->confirmDeleteComponent   = 'Do you want to remove this component?';

$lang->assetlib->lib       = 'Library';
$lang->assetlib->selectLib = 'Select Library';
$lang->assetlib->noLibrary = 'No library exists. Please create one first.';

$lang->assetlib->featureBar['browse']['all']   = 'All';
$lang->assetlib->featureBar['browse']['draft'] = 'Pending';

$lang->assetlib->featureBar['caselib']['all'] = $lang->assetlib->all;

$lang->assetlib->statusList['active'] = 'Inlib';
$lang->assetlib->statusList['draft']  = 'Pending';

$lang->assetlib->resultList['pass']   = 'Pass';
$lang->assetlib->resultList['reject'] = 'Reject';

$lang->assetlib->byQuery = 'Search';
